<?php

namespace Bydedi\Tracking\Criteo;

/**
 * Class Criteo
 * @package Bydedi\Tracking\Criteo
 */
class Criteo
{


    /**
     * @var array
     */
    static protected $config = null;

    /**
     * Init la config de criteo
     *
     * @param array $config :
     *  - position : tracking_footer | tracking_header
     *  - display : 1 | 0
     *  - account_id :
     *  - type : d for desktop | m for mobile | t for tablet
     */
    static public function init($config = array())
    {
        self::$config = $config;

        if (empty(self::$config["type"])) self::$config["type"] = "d";
    }

    /**
     * Check if criteo is initialized.
     * If not trigger a warning error
     */
    static protected function triggerErrorIfNotInit()
    {
        if (is_null(self::$config)) {
            trigger_error("Criteo n'est pas initailisé", E_USER_WARNING);
        }
    }

    /**
     * @param array $param
     */
    static public function panier($param = array())
    {

        self::triggerErrorIfNotInit();

        $out = "";

        if (self::$config['display']) {

            $out = "<script type=\"text/javascript\" src=\"//static.criteo.net/js/ld/ld.js\" async=\"true\"></script>
                    <script type=\"text/javascript\">
                        window.criteo_q = window.criteo_q || [];
                        window.criteo_q.push(
                            { event: \"setAccount\", account: " . self::$config["account_id"] . " },
                            { event: \"setSiteType\", type: \"" . self::$config["type"] . "\" },
                            { event: \"setEmail\", email: \"" . self::getEmailClient() . "\" },
                            { event: \"viewBasket\", item: " . self::getJsonListProducts($param["extra"]["produits"]) . "});
                    </script>";

        }

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $out);
        }
    }

    /**
     * @param array $param
     */
    static public function listing($param = array())
    {

        self::triggerErrorIfNotInit();

        $out = "";

        if (self::$config['display']) {

            $out = "<script type=\"text/javascript\" src=\"//static.criteo.net/js/ld/ld.js\" async=\"true\"></script>
                    <script type=\"text/javascript\">
                        window.criteo_q = window.criteo_q || [];
                        window.criteo_q.push(
                            { event: \"setAccount\", account: " . self::$config["account_id"] . " },
                            { event: \"setSiteType\", type: \"" . self::$config["type"] . "\" },
                            { event: \"setEmail\", email: \"" . self::getEmailClient() . "\" },
                            { event: \"viewList\", item: [" . self::getListProduitId($param["extra"]["produits"]) . "] }
                        );
                    </script>";

        }


        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $out);
        }
    }

    /**
     * @param array $param
     */
    static public function homepage($param = array())
    {

        self::triggerErrorIfNotInit();

        $out = "";

        if (self::$config['display']) {

            //cto home tag
            $out = "<script type=\"text/javascript\" src=\"//static.criteo.net/js/ld/ld.js\" async=\"true\"></script>
                    <script type=\"text/javascript\">
                        window.criteo_q = window.criteo_q || [];
                        window.criteo_q.push(
                            { event: \"setAccount\", account: " . self::$config["account_id"] . " },
                            { event: \"setSiteType\", type: \"" . self::$config["type"] . "\" },
                            { event: \"setEmail\", email: \"" . self::getEmailClient() . "\" },         
                            { event: \"viewHome\"}
                        ); 
                    </script>";

        }

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $out);
        }
    }

    /**
     * @param array $param
     */
    static public function produit($param = array())
    {

        self::triggerErrorIfNotInit();

        $out = "";

        if (self::$config['display']) {

            $out = "<script type=\"text/javascript\" src=\"//static.criteo.net/js/ld/ld.js\" async=\"true\"></script> 
                    <script type=\"text/javascript\"> 
                        window.criteo_q = window.criteo_q || []; 
                        window.criteo_q.push(
                            { event: \"setAccount\", account: " . self::$config["account_id"] . " },
                            { event: \"setSiteType\", type: \"" . self::$config["type"] . "\" },
                            { event: \"setEmail\", email: \"" . self::getEmailClient() . "\" },         
                            { event: \"viewItem\", item: \"" . self::getProduitId($param["extra"]["produit"]) . "\" } 
                        ); 
                    </script>";

        }

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $out);
        }
    }

    /**
     * @param array $param
     */
    static public function paiement($param = array())
    {

        self::triggerErrorIfNotInit();

        $out = "";


        if (self::$config['display']) {

            $out = "<script type=\"text/javascript\" src=\"//static.criteo.net/js/ld/ld.js\" async=\"true\"></script> 
                    <script type=\"text/javascript\"> 
                        window.criteo_q = window.criteo_q || []; 
                        window.criteo_q.push(         
                            { event: \"setAccount\", account: " . self::$config["account_id"] . " },         
                            { event: \"setSiteType\", type: \"" . self::$config["type"] . "\" },     
                            { event: \"setEmail\", email: \"" . self::getEmailClient() . "\" },         
                            { event: \"trackTransaction\", id: \"" . $param["extra"]["commande_id"] . "\", item: "
                   . self::getJsonListProducts($param["extra"]["produits"]) . "}); 
                    </script>";

        }

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $out);
        }
    }

    static public function setMobile()
    {
        self::triggerErrorIfNotInit();

        self::$config["type"] = "m";
    }

    static private function getEmailClient()
    {
        return (!empty($_SESSION["client_email"])) ? $_SESSION["client_email"] : "";
    }

    static private function getJsonListProducts($arrProd = array())
    {
        if (empty($arrProd)) return "";

        $arrProducts = [];

        foreach ($arrProd as $p) {
            $prod["id"]       = self::getProduitId($p);
            $prod["price"]    = (!empty($p["prix_ttc"])) ? $p['prix_ttc'] : $p["produit_prix_ttc"];
            $prod["quantity"] = (!empty($p["qte"])) ? $p['qte'] : $p["produit_quantite"];
            $arrProducts[]    = $prod;
        }

        return json_encode($arrProducts);
    }

    static private function getListProduitId($arrProd = array())
    {
        $arrIds = [];
        foreach ($arrProd as $p) {
            $arrIds[] = "\"" . self::getProduitId($p) . "\"";
        }

        return implode(", ", $arrIds);
    }

    static private function getProduitId($produit)
    {
        return $produit["produit_id"];
    }
}
